@@ -36,6 +36,8 @@ class ModelResponse:
                 {
                     key: result[key],
                     "logprob": result["logprob"],
+                    "tokens": result["tokens"],
+                    "token_logprobs": result["token_logprobs"],
                 }
                 if key == "text"
                 else {
