@@ -27,9 +27,9 @@ class AI21Client(Client):
         "n": ("numResults", 1),
         "top_p": ("topP", 1.0),
         "stop_sequences": ("stopSequences", []),
-        "client_timeout": ("client_timeout", 60),  # seconds
     }
     REQUEST_CLS = LMRequest
+    NAME = "ai21"
 
     def connect(
         self,
@@ -94,12 +94,13 @@ class AI21Client(Client):
         """
         return {"model_name": "ai21", "engine": getattr(self, "engine")}
 
-    def format_response(self, response: Dict) -> Dict[str, Any]:
+    def format_response(self, response: Dict, request: Dict) -> Dict[str, Any]:
         """
         Format response to dict.
 
         Args:
             response: response
+            request: request
 
         Return:
             response as dict
@@ -110,7 +111,7 @@ class AI21Client(Client):
             "choices": [
                 {
                     "text": item["data"]["text"],
-                    "logprobs": item["data"]["tokens"],
+                    "token_logprobs": item["data"]["tokens"],
                 }
                 for item in response["completions"]
             ],
