@@ -1,11 +1,12 @@
 """Hugging Face client."""
 import logging
-from typing import Any, Callable, Dict, Optional, Tuple
+from typing import Any, Dict, Optional
 
 import requests
 
 from manifest.clients.client import Client
-from manifest.request import LMRequest, Request
+from manifest.request import DEFAULT_REQUEST_KEYS, LMRequest, Request
+from manifest.response import Response
 
 logger = logging.getLogger(__name__)
 
@@ -22,9 +23,9 @@ class HuggingFaceClient(Client):
         "top_k": ("top_k", 50),
         "repetition_penalty": ("repetition_penalty", 1.0),
         "do_sample": ("do_sample", True),
-        "client_timeout": ("client_timeout", 120),  # seconds
     }
     REQUEST_CLS = LMRequest
+    NAME = "huggingface"
 
     def connect(
         self,
@@ -81,7 +82,7 @@ class HuggingFaceClient(Client):
     def get_score_prompt_request(
         self,
         request: Request,
-    ) -> Tuple[Callable[[], Dict], Dict]:
+    ) -> Response:
         """
         Get the logit score of the prompt via a forward pass of the model.
 
@@ -92,26 +93,26 @@ class HuggingFaceClient(Client):
             request function that takes no input.
             request parameters as dict.
         """
-        request_params = request.to_dict(self.PARAMS)
+        request_params = self.get_request_params(request)
         retry_timeout = request_params.pop("client_timeout")
+        for key in DEFAULT_REQUEST_KEYS:
+            request_params.pop(key, None)
         # Do not add params like we do with request as the model isn't sampling
         request_params = {"prompt": request.prompt}
 
-        def _run_completion() -> Dict:
-            post_str = self.host + "/score_sequence"
-            try:
-                res = requests.post(
-                    post_str,
-                    json=request_params,
-                    timeout=retry_timeout,
-                )
-                res.raise_for_status()
-            except requests.Timeout as e:
-                logger.error("HF request timed out. Increase client_timeout.")
-                raise e
-            except requests.exceptions.HTTPError as e:
-                logger.error(res.text)
-                raise e
-            return res.json()
-
-        return _run_completion, request_params
+        post_str = self.host + "/score_sequence"
+        try:
+            res = requests.post(
+                post_str,
+                json=request_params,
+                timeout=retry_timeout,
+            )
+            res.raise_for_status()
+        except requests.Timeout as e:
+            logger.error("HF request timed out. Increase client_timeout.")
+            raise e
+        except requests.exceptions.HTTPError as e:
+            logger.error(res.text)
+            raise e
+        response_dict = res.json()
+        return Response(response_dict, cached=False, request_params=request_params)
