@@ -4,6 +4,17 @@ from typing import Any, Dict, List, Union
 
 import numpy as np
 
+RESPONSE_CONSTRUCTORS = {
+    "diffuser": {
+        "logits_key": "token_logprobs",
+        "item_key": "array",
+    },
+    "tomadiffuser": {
+        "logits_key": "token_logprobs",
+        "item_key": "array",
+    },
+}
+
 
 class NumpyArrayEncoder(json.JSONEncoder):
     """Numpy array encoder."""
@@ -20,12 +31,13 @@ class Response:
 
     def __init__(
         self,
-        response: Dict,
+        response: Dict,  # TODO: make pydantic model
         cached: bool,
-        request_params: Dict,
+        request_params: Dict,  # TODO: use request pydantic model
         generation_key: str = "choices",
-        logits_key: str = "logprobs",
+        logits_key: str = "token_logprobs",
         item_key: str = "text",
+        usage_key: str = "usage",
     ):
         """
         Initialize response.
@@ -41,6 +53,7 @@ class Response:
         self.generation_key = generation_key
         self.logits_key = logits_key
         self.item_key = item_key
+        self.usage_key = usage_key
         self.item_dtype = None
         if isinstance(response, dict):
             self._response = response
@@ -55,6 +68,16 @@ class Response:
                 "Response must be serialized to a dict with a nonempty"
                 f" list of choices. Response is\n{self._response}."
             )
+        # Turn off usage if it is not in response
+        if self.usage_key not in self._response:
+            self.usage_key = None
+        else:
+            if not isinstance(self._response[self.usage_key], list):
+                raise ValueError(
+                    "Response must be a list with usage dicts, one per choice."
+                    f" Response is\n{self._response}."
+                )
+
         if self.item_key not in self._response[self.generation_key][0]:
             raise ValueError(
                 "Response must be serialized to a dict with a "
@@ -68,8 +91,8 @@ class Response:
                 self._response[self.generation_key][0][self.logits_key], list
             ):
                 raise ValueError(
-                    "Response must be serialized to a dict with a "
-                    "list of choices with logprobs field"
+                    f"{self.logits_key} must be a list of items "
+                    "one for each token in the choice."
                 )
         if isinstance(
             self._response[self.generation_key][0][self.item_key], np.ndarray
